# Contributing

To install pyqrlew developper environment, clone [pyqrlew repo](https://github.com/Qrlew/pyqrlew).

Make sure you have [maturin](https://github.com/PyO3/maturin) installed.

Run:
```bash
maturin develop
```

